__author__ = 'jfindley'
import sys, os
sys.path.append(os.path.join("..", "lib"))
from generator import ZMapGenerator
from zmapper import apply_map_to_gcode


if __name__ == "__main__":
    # Sample gcode
    gcode_dir = os.path.join("..", "gcode")
    gcode_in = os.path.join(gcode_dir, "test_kiss.gcode")
    gcode_out = os.path.join(gcode_dir, "test_kiss_zmapped.gcode")

    # CSV
    csv_dir = os.path.join("..", "csv")
    csv = os.path.join(csv_dir, "zmap.csv")

    # Printer capabilities
    speed_max_travel = 15000    # speed to go from home to zero
    speed_max_dot = 9000        # speed to go from point to point
    wait_time_home = 5          # time (seconds) to wait for all axes to home
    wait_time_xyz_zero = 3      # time (seconds) to wait for all axes to reach zero
    wait_time_point = 0.3         # time (seconds) to wait for printer to settle on point. If print head stutters, you're going too fast
    wait_time_row = 0.5           # time (seconds) to dwell on the end of a row
    z_height_row_change = 15    # how high to move print head before moving to start of next row

    # Build plate specification
    build_plate_radius = 70        # Orion build plate radius, Set to whatever it should be for yours

    # Calibration granularity
    point_spacing = 2          # size of point spacing in mm, less takes longer

    # Because I'm not very good at math, we need to adhere to this.
    columns = (build_plate_radius*2)/float(point_spacing)
    if int(columns) != columns:
        raise Exception("Build plate radius not evenly divisible by point spacing.")

    # Calibration style
    demo = True                 # If True, use random numbers as measurements, otherwise prompt user for measurements at each point

    # COM Port, set to whatever RH uses.
    com_port = "FAKE"                   # FAKE, will just print gcode. Set to your com port to send to printer instead
    baud_rate = 0                  # Intentional error to get this value set appropriately.

    zm = ZMapGenerator(
        com_port=com_port,
        baud_rate=baud_rate,
        speed_max_travel=speed_max_travel,
        speed_max_dot=speed_max_dot,
        wait_time_home=wait_time_home,
        wait_time_xyz_zero=wait_time_xyz_zero,
        wait_time_point=wait_time_point,
        wait_time_row=wait_time_row,
        z_height_row_change=z_height_row_change,
        r=build_plate_radius,
        step_size=point_spacing,
        csv_file=csv,
        demo=True)

    # Display the offsets in a 3d scatter plot
    zm.generate_buildplate_image()

    # Use the zmap to post-process gcode
    apply_map_to_gcode(gcode_in, csv, gcode_out)